hdf5lib-package: hdf5lib: Headers and Static Libraries for 'HDF5'

hdf5lib-packageR Documentation

hdf5lib: Headers and Static Libraries for 'HDF5'

Description

hdf5lib provides a self-contained, static build of the HDF5 C library (version 1.14.6) and zlib (version 1.3.1).

Details

This package provides no R functions and is intended for R package developers to use in the LinkingTo field of their DESCRIPTION file. It allows other R packages to easily link against HDF5 without requiring users to install any system-level dependencies.

Author(s)

Maintainer: Daniel P. Smith dansmith01@gmail.com (ORCID)

Other contributors:

  • The HDF Group (Copyright holder of the HDF5 library) [copyright holder]

  • Jean-loup Mark (Copyright holder of the zlib library) [copyright holder]

  • Gailly Adler (Copyright holder of the zlib library) [copyright holder]

See Also

Useful links:


hdf5lib documentation built on May 15, 2026, 9:06 a.m.