| hdf5lib-package | R Documentation |
hdf5lib provides a self-contained, static build of the HDF5 C library
(version 1.14.6) and zlib (version 1.3.1).
This package provides no R functions and is intended for R package
developers to use in the LinkingTo field of their DESCRIPTION file.
It allows other R packages to easily link against HDF5 without
requiring users to install any system-level dependencies.
Maintainer: Daniel P. Smith dansmith01@gmail.com (ORCID)
Other contributors:
The HDF Group (Copyright holder of the HDF5 library) [copyright holder]
Jean-loup Mark (Copyright holder of the zlib library) [copyright holder]
Gailly Adler (Copyright holder of the zlib library) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.